/* glu.h */

/*
 * Mesa - a 3-D graphics library
 * Version:  1.0 beta
 * Copyright (C) 1995  Brian Paul  (brianp@ssec.wisc.edu)
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */


#ifndef GLU_H
#define GLU_H


#ifdef __cplusplus
extern "C" {
#endif

#include "GL/gl.h"


typedef enum {
	/* Quadric draw styles */
	GLU_FILL,
	GLU_LINE,
	GLU_SILHOUETTE,
	GLU_POINT,

	/* Quadric orientation */
	GLU_OUTSIDE,
	GLU_INSIDE,

	/* Normal vectors */
	GLU_NONE,
	GLU_FLAT,
	GLU_SMOOTH,

	/* NURBS */
	GLU_SAMPLING_TOLERANCE,
	GLU_DISPLAY_MODE,
	GLU_CULLING,
	GLU_AUTO_LOAD_MATRIX,

	GLU_INVALID_ENUM,
	GLU_INVALID_VALUE,
	GLU_OUT_OF_MEMORY,
	GLU_ERROR
} GLUenum;


typedef struct {
	GLUenum	DrawStyle;	/* GLU_FILL, LINE, SILHOUETTE, or POINT */
	GLUenum Orientation;	/* GLU_INSIDE or GLU_OUTSIDE */
	GLboolean TextureFlag;	/* Generate texture coords? */
	GLUenum Normals;	/* GLU_NONE, GLU_FLAT, or GLU_SMOOTH */
} GLUquadricObj;


typedef struct {
	GLboolean Culling;
} GLUnurbsObj;



extern void gluLookAt( GLdouble eyex, GLdouble eyey, GLdouble eyez,
		       GLdouble centerx, GLdouble centery, GLdouble centerz,
		       GLdouble upx, GLdouble upy, GLdouble upz );


extern void gluOrtho2D( GLdouble left, GLdouble right,
		        GLdouble bottom, GLdouble top );


extern void gluPerspective( GLdouble fovy, GLdouble aspect,
			    GLdouble zNear, GLdouble zFar );


extern void gluPickMatrix( GLdouble x, GLdouble y,
			   GLdouble width, GLdouble height,
			   GLint viewport[4] );

extern int gluProject( GLdouble objx, GLdouble objy, GLdouble objz,
		       const GLdouble modelMatrix[16],
		       const GLdouble projMatrix[16],
		       const GLint viewport[4],
		       GLdouble *winx, GLdouble *winy, GLdouble *winz );

extern int gluUnProject( GLdouble winx, GLdouble winy, GLdouble winz,
			 const GLdouble modelMatrix[16],
			 const GLdouble projMatrix[16],
			 const GLint viewport[4],
			 GLdouble *objx, GLdouble *objy, GLdouble *objz );


extern GLUquadricObj *gluNewQuadric( void );

extern void gluDeleteQuadric( GLUquadricObj *state );

extern void gluQuadricDrawStyle( GLUquadricObj *quadObject,
				 GLUenum drawStyle );

extern void gluQuadricOrientation( GLUquadricObj *quadObject,
				   GLUenum orientation );

extern void gluCylinder( GLUquadricObj *qobj,
			 GLdouble baseRadius,
			 GLdouble topRadius,
			 GLdouble height,
			 GLint slices, GLint stacks );

extern void gluSphere( GLUquadricObj *qobj,
		       GLdouble radius, GLint slices, GLint stacks );

extern void gluDisk( GLUquadricObj *qobj,
		     GLdouble innerRadius, GLdouble outerRadius,
		     GLint slices, GLint loops );


extern int gluScaleImage( GLenum format,
			  GLint widthin, GLint heightin,
			  GLenum typein, const void *datain,
			  GLint widthout, GLint heightout,
			  GLenum typeout, void *dataout );


/* not implemented: */

extern const GLubyte* gluErrorString( GLenum errorCode );

extern int gluBuild1DMipmaps( GLenum target, GLint components,
			      GLint width, GLenum format,
			      GLenum type, const void *data );

extern int gluBuild2DMipmaps( GLenum target, GLint components,
			      GLint width, GLint height, GLenum format,
			      GLenum type, const void *data );

extern void gluQuadricCallback( GLUquadricObj *qobj,
			        GLenum which, void (*fn)() );

extern void gluQuadricNormals( GLUquadricObj *quadObject, GLenum normals );

extern void gluQuadricTexture( GLUquadricObj *quadObject,
			       GLboolean textureCoords );

extern void gluPartialDisk( GLUquadricObj *qobj, GLdouble innerRadius,
			    GLdouble outerRadius, GLint slices, GLint loops,
			    GLdouble startAngle, GLdouble sweepAngle );


/*
 *
 * Nurbs
 *
 */


extern GLUnurbsObj *gluNewNurbsRenderer( void );

extern void gluDeleteNurbsRenderer( GLUnurbsObj *nobj );

extern void gluLoadSamplingMatrices( GLUnurbsObj *nobj,
				     const GLfloat modelMatrix[16],
				     const GLfloat projMatrix[16],
				     const GLint viewport[4] );

extern void gluNurbsProperty( GLUnurbsObj *nobj,
       	                      GLenum property,
                              GLfloat value );

extern void gluBeginCurve( GLUnurbsObj *nobj );

extern void gluEndCurve( GLUnurbsObj * nobj );

extern void gluNurbsCurve( GLUnurbsObj *nobj, GLint nknots, GLfloat *knot,
			   GLint stride, GLfloat *ctlarray, GLint order,
			   GLenum type );

extern void gluBeginSurface( GLUnurbsObj *nobj );

extern void gluEndSurface( GLUnurbsObj * nobj );

extern void gluNurbsSurface( GLUnurbsObj *nobj,
			     GLint sknot_count, GLfloat *sknot,
			     GLint tknot_count, GLfloat *tknot,
			     GLint s_stride, GLint t_stride,
			     GLfloat *ctlarray,
			     GLint sorder, GLint torder,
        	             GLenum type );


#ifdef __cplusplus
}
#endif


#endif
