/* xmesa.h */

/*
 * Mesa 3-D graphics library
 * Version:  1.0 beta
 * Copyright (C) 1995  Brian Paul  (brianp@ssec.wisc.edu)
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */


/*
 * Mesa/X11 interface.  This header file serves as the documentation for
 * the Mesa/X11 interface functions.
 */


/* Sample Usage:

1. Make the X11 calls needed to open the display, select a visual, make a
   colormap, open a window, etc.

2. Call XMesaCreateContext() to make a rendering context.

3. Call XMesaMakeCurrent() to make the context the active one.

4. Make gl* calls to render your graphics.

5. When exiting, call XMesaDestroyContext().

*/




#ifndef XMESA_H
#define XMESA_H


#ifdef __cplusplus
extern "C" {
#endif


#include <X11/Xlib.h>
#include "gl.h"


/*
 * This is a XMesa context 'handle':
 */
typedef struct xmesa_context *XMesaContext;



/*
 * Create a new XMesaContext for rendering into an X11 window.  You must
 * have already created the window of correct visual type and with an
 * appropriate colormap.
 *
 * Input:  display - X11 display
 *         window - X11 window to render into.
 *         rgb_flag - GL_TRUE = RGB mode,
 *                    GL_FALSE = color index mode
 *         db_flag - GL_TRUE = double-buffered,
 *                   GL_FALSE = single buffered
 *         ximage_flag - GL_TRUE = use an XImage for back buffer,
 *                       GL_FALSE = use an off-screen pixmap for back buffer
 * Return:  a XMesa_context or NULL if error.
 */
extern XMesaContext XMesaCreateContext( Display *display,
				        Window window,
					GLboolean rgb_flag,
					GLboolean db_flag,
				        GLboolean ximage_flag );


/*
 * Destroy a rendering context as returned by XMesaCreateContext()
 */
extern void XMesaDestroyContext( XMesaContext ctx );


/*
 * Make the specified context the current one.
 */
extern void XMesaMakeCurrent( XMesaContext ctx );


/*
 * Return a handle to the current context.
 */
extern XMesaContext XMesaGetCurrentContext( void );


/*
 * Swap the front and back buffers for the current context.  No action
 * taken if the context is not double buffered.
 */
extern void XMesaSwapBuffers( void );


#ifdef __cplusplus
}
#endif


#endif
